<?php

namespace Drupal\post_api\Event;

use Symfony\Component\EventDispatcher\Event;

/**
 * Defines the "Queue Item Processed" event.
 */
class QueueItemProcessedEvent extends Event {

  const EVENT_NAME = 'post_api_queue_item_processed_event';

  /**
   * The HTTP response code received from POST request.
   *
   * @var int
   */
  protected $responseCode;

  /**
   * The queue item data.
   *
   * @var array
   */
  protected $queueItemData;

  /**
   * QueueItemProcessedEvent constructor.
   *
   * @param int $responseCode
   *   The HTTP response code received from POST request.
   * @param array $queueItemData
   *   The queue item data.
   */
  public function __construct(int $responseCode, array $queueItemData) {
    $this->responseCode = $responseCode;
    $this->queueItemData = $queueItemData;
  }

  /**
   * Returns the HTTP response code.
   *
   * @return int
   *   The HTTP response code.
   */
  public function getResponseCode() {
    return $this->responseCode;
  }

  /**
   * Returns the queue item data.
   *
   * @return array
   *   The queue item data.
   */
  public function getQueueItem() {
    return $this->queueItemData;
  }

}
